#' Clean spawning capacity
#'
#' Combine large river, small stream and floodplain spawning capacities.
#'
#' @param run_pop which pop to run
#' @param df_cap_egg output of `hab_calc_egg_cap()`
#'
#' @export

hab_calc_capacity_spawn <- function(df_cap_egg, run_pop){

  fecundity <- get(paste0('params_hab_',run_pop))$fecundity
  adult_per_redd <- get(paste0('params_hab_',run_pop))$adult_per_redd

  df_cap_egg %>%
    tidytable::summarize(
      eggs = sum(eggs, na.rm = T),
      adults = sum(eggs / fecundity * adult_per_redd, na.rm = T),
      .by = c(subbasin_num, era, scenario)) %>%
    tidytable::pivot_longer(
      c(eggs, adults),
      names_to = "life.stage",
      values_to = "capacity")
}



