#' Calculate egg to fry productivity
#'
#' Egg to fry productivity is weighted by egg capacity on a reach basis.
#'
#' @param df_flowline output of hab_clean_flowline()
#' @param df_egg_cap Output of hab_calc_egg_cap()
#' @param run_era which era to run
#' @export


hab_calc_productivity_egg2fry <- function(df_flowline, df_egg_cap, run_era){

  # calculate change in incubation productivity based on climate
  flow_adjustment <- switch(
    run_era,
    hist = 1, # if run_era == "hist", return 1
    curr = 1,
    mid = peakq_change_mid,
    late = peakq_change_late)

  # calc ratio of survival in climate-adjusted median Q to current median Q
  surv_adjustment <- calc_e2f_surv(peak_q_median*flow_adjustment)/
    calc_e2f_surv(peak_q_median)

  df_flowline %>%
    select(noaaid, ef_surv_current, ef_surv_hist) %>%
    tidytable::right_join(df_egg_cap, by = c("noaaid")) %>%
    mutate(
      ef_surv = apply_rest_action(
        ef_surv_current,
        ef_surv_hist,
        1,
        ef_intensity_scalar
      )) %>%
    tidytable::summarize(
      survival = weighted.mean(ef_surv, eggs, na.rm =T),
      .by = c(subbasin_num, era, scenario)) %>%
    mutate(
      life.stage = "egg.to.fry",
      survival = survival*surv_adjustment)

}
