#' Reach-level passage values.
#'
#' A dataset containing the passage associated with each reach under each
#' scenario
#'
#' @format A tibble with 113,400 rows and 3 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{pass_tot_scenario}{passage to reach under given scenario}
#'   \item{scenario}{which diagnostic or restoration scenario}
#' }
#' @source \describe{generated from the habitat scenario model and local input}
"barriers_df"

#' Reach-level width values.
#'
#' A dataset containing the summer and winter widths associated with each reach
#'
#' @format A data frame with 5,400 rows and 3 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{width_s}{summer wetted width, meters}
#'   \item{width_w}{winter wetted width, meters}
#'   \item{RI}{default recurrence interval, 2}
#'   \item{a}{flow-modifying coefficient `a`}
#'   \item{b}{flow-modifying coefficient `b`}
#'   \item{era}{era for which coefficients are valid}
#'   \item{lowQ_i}{median low flow at gage}
#' }
#' @source \describe{generated from the habitat scenario model and SSN models}
"width_df"

#' Reach-level temperature values.
#'
#' A dataset containing the summer and winter widths associated with each reach
#'
#' @format A tibble with 226,800 rows and 6 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{era}{era under which scenario is applied}
#'   \item{scenario}{which diagnostic or restoration scenario}
#'   \item{temp_Jn121}{mean maximum daily temperature between June 1-21}
#'   \item{temp_7DADM}{7-day average daily max August temperature}
#'   \item{temp_prespawn}{7-day average daily max August temperature}
#' }
#' @source \describe{generated from the habitat scenario model and SSN models}
"temperature_df"

#' Reach-level scenario values.
#'
#' A dataset containing scalars that vary by scenario and reach
#'
#' @format A tibble with 226,800 rows and 6 variables:
#' \describe{
#'   \item{scenario}{which diagnostic or restoration scenario}
#'   \item{noaaid}{reach ID}
#'   \item{Fine_sediment}{flag whether or not fine sediment values are altered}
#'   \item{LR}{flag whether or not large river banks are altered}
#'   \item{rest_perc}{percent of area influenced under scenario}
#'   \item{primary_cr_only}{deprecated}
#'   \item{managed_forest}{flag whether or not manage forest scenario is run}
#'   \item{beaver_intensity_scalar}{intensity of beaver restoration}
#'   \item{temp_intensity_scalar}{intensity of temperature restoration}
#'   \item{fp_intensity_scalar}{intensity of floodplain restoration}
#'   \item{wood_intensity_scalar}{intensity of wood restoration}
#'   \item{ef_intensity_scalar}{intensity of fine sediment restoration}
#'   \item{lr_intensity_scalar}{intensity of large river bank restoration}
#' }
#' @source \describe{generated from the habitat scenario model}
"scenarios_df"

#' Reach-level attributes.
#'
#' A dataset containing attributes for each population for each reach
#'
#' @format A tibble with 20,460 rows and 18 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{Habitat}{habitat type as used in HARP}
#'   \item{slope}{stream gradient}
#'   \item{BF_width}{bankfull width (m)}
#'   \item{length}{length (m)}
#'   \item{lc}{landcover class}
#'   \item{fpw}{floodplain width (m)}
#'   \item{noaa_subba}{subbasin used in HARP}
#'   \item{Area_km2}{drainage area (km^2)}
#'   \item{ef_surv_current}{current median incubation survival}
#'   \item{ef_surv_hist}{historical median incubation survival}
#'   \item{subbasin_num}{subbasin number used in HARP}
#'   \item{pond_overlap}{logical indicating if reach overlaps a pond}
#'   \item{lg_slough}{logical indicating if reach is a large slough}
#'   \item{psm}{prespawn mortality (deterministic)}
#'   \item{pop}{HARP population}
#'   \item{spawn}{logical indicating if pop spawns in reach}
#'   \item{rear}{logical indicating if pop rears in reach}
#' }
#' @source \describe{multiple sources, see NOAA HARP report}
"flowline_clean"

#' Time series simulation data.
#'
#' A dataset containing attributes for each population for each reach
#'
#' @format A tibble with 75,000 rows and 4 variables:
#' \describe{
#'   \item{var}{which variable is modified}
#'   \item{year}{simulation year (1:150)}
#'   \item{run}{simulation number}
#'   \item{value}{value of variable `var`}
#' }
#' @source \describe{MARSS simulation modeling}
"df_marss"

#' Time series simulation data.
#'
#' A dataset containing attributes for each population for each reach
#'
#' @format A data frame with 75,000 rows and 4 variables:
#' \describe{
#'   \item{var}{which variable is modified}
#'   \item{year}{simulation year (1:150)}
#'   \item{run}{simulation number}
#'   \item{value}{value of variable `var`}
#' }
#' @source \describe{MARSS simulation modeling}
"df_marss"

#' Calibrated Chinook LCM parameters for Stillaguamish Model 2.
#'
#' A dataset containing calibrated LCM parameters
#'
#' @format A named vector with 4 elements:
#' \describe{
#'   \item{subyr_ratio}{portion of subyearlings that outmigrate in spring}
#'   \item{ps_parr_surv}{smolt trap to-spawning survival of subyearlings}
#'   \item{fry_migr_prod}{migration survival of fry migrants}
#'   \item{ps_yr_surv}{smolt trap to-spawning survival of subyearlings}
#' }
#' @source \describe{Calibrated to minimize RMSE}
"params_chinook_noPSM"

#' Coho LCM parameters for Stillaguamish LCM.
#'
#' A dataset containing LCM parameters
#'
#' @format A named vector with 9 elements:
#' \describe{
#'   \item{pop_init}{initiation population size}
#'   \item{fecund}{fecundity}
#'   \item{sex_ratio}{migration survival of fry migrants}
#'   \item{percent_fry_migrants}{percent of fry migrating in spring}
#'   \item{fry_colonization}{fry survival during colonization}
#'   \item{bay}{estuary survival}
#'   \item{so}{ocean survival}
#'   \item{b2}{ocean maturation rate}
#'   \item{hr}{harvest rate}
#' }
#' @source \describe{Various sources, see LCM report}
'params_coho'

#' Chinook LCM parameters for Stillaguamish LCM.
#'
#' A dataset containing LCM parameters
#'
#' @format A named vector with 26 elements:
#' \describe{
#'   \item{pop_init}{initiation population size}
#'   \item{fecund}{fecundity}
#'   \item{sex_ratio_hor}{percent female HOR}
#'   \item{sex_ratio_nor}{percent female NOR}
#'   \item{fry_migr_prod}{migration survival of fry migrants}
#'   \item{delta_prod}{estuary survival}
#'   \item{ps_parr_surv}{smolt trap to-spawning survival of subyearlings}
#'   \item{ps_yr_surv}{smolt trap to-spawning survival of subyearlings}
#'   \item{so1}{first year ocean survival}
#'   \item{so2}{second year ocean survival}
#'   \item{so3}{third year ocean survival}
#'   \item{so4}{fourth year ocean survival}
#'   \item{so5}{fifth year ocean survival}
#'   \item{b0_2}{maturation rate age 0.2}
#'   \item{b0_3}{maturation rate age 0.3}
#'   \item{b0_4}{maturation rate age 0.4}
#'   \item{b1_2}{maturation rate age 1.2}
#'   \item{b1_3}{maturation rate age 1.3}
#'   \item{subyr_ratio}{portion of subyearlings that outmigrate in spring}
#'   \item{tot_bs}{number of adults taken as broodstock}
#'   \item{nf_release}{number of hatchery smolts released in the North Fork}
#'   \item{sf_release}{number of hatchery smolts released in the South Fork}
#'   \item{fw_surv_h}{outmigration survival of hatchery smolts}
#'   \item{sw_surv_h}{ocean survival of hatchery smolts}
#'   \item{rrs_h}{relative reproductive success of hatchery-origin fish}
#'   \item{hr}{harvest rate}
#' }
#' @source \describe{Various sources, see LCM report}
'params_fall_chinook'

#' Steelhead LCM parameters for Stillaguamish LCM.
#'
#' A dataset containing LCM parameters
#'
#' @format A named vector with 26 elements:
#' \describe{
#'   \item{pop_init}{initiation population size}
#'   \item{fecund_first}{fecundity of first-time spawners}
#'   \item{fecund_first}{fecundity of respawners}
#'   \item{sex_ratio}{percent female}
#'   \item{percent_fall_migrants}{fraction of juveniles migrating in fall}
#'   \item{percent_spring_migrants}{fraction of juveniles migrating in spring}
#'   \item{prop_age1_smolts_w}{fraction of winter-run juveniles outmigrating as age 1}
#'   \item{prop_age2_smolts_w}{fraction of winter-run juveniles outmigrating as age 2}
#'   \item{prop_age1_smolts_s}{fraction of summer-run juveniles outmigrating as age 1}
#'   \item{prop_age2_smolts_s}{fraction of summer-run juveniles outmigrating as age 2}
#'   \item{bay_surv_w}{estuary survival for winter-run smolts}
#'   \item{bay_surv_s}{estuary survival for summer-run smolts}
#'   \item{so}{annual marine survival}
#'   \item{b1_1_w}{maturation rate age 1.1 winter-run}
#'   \item{b1_2_w}{maturation rate age 1.2 winter-run}
#'   \item{b2_1_w}{maturation rate age 2.1 winter-run}
#'   \item{b2_2_w}{maturation rate age 2.2 winter-run}
#'   \item{b3_1_w}{maturation rate age 3.1 winter-run}
#'   \item{b1_1_s}{maturation rate age 1.1 summer-run}
#'   \item{b1_2_s}{maturation rate age 1.2 summer-run}
#'   \item{b2_1_s}{maturation rate age 2.1 summer-run}
#'   \item{b2_2_s}{maturation rate age 2.2 summer-run}
#'   \item{b3_1_s}{maturation rate age 3.1 summer-run}
#'   \item{kelt_rate}{respawn rate}
#'   \item{hr}{harvest rate}
#' }
#' @source \describe{Various sources, see LCM report}
'params_steelhead'

#' Chum habitat parameters - DEPRECATED
#'
#' A dataset containing habitat parameters
#'
#' @format A named list with 10 elements:
#' \describe{
#'   \item{fecundity}{fecundity}
#'   \item{redd_area}{size of redd}
#'   \item{adult_per_redd}{adults per redd}
#'   \item{density}{maximum rearing densities by habitat type}
#'   \item{survival}{seasonal survival by habitat type}
#'   \item{lr_wd_s_bank}{summer large river wood density associated with banks}
#'   \item{lr_wd_s_bar}{summer large river wood density associated with bars}
#'   \item{lr_wd_w_bank}{winter large river wood density associated with banks}
#'   \item{lr_wd_w_bar}{winter large river wood density associated with bars}
#'   \item{prespawn_surv_raw}{natural prespawn mortality}
#'   }
#' @source \describe{Various sources, see LCM report}
'params_hab_chum'

#' Coho habitat parameters for habitat model
#'
#' A dataset containing habitat parameters
#'
#' @format A named list with 10 elements:
#' \describe{
#'   \item{fecundity}{fecundity}
#'   \item{redd_area}{size of redd}
#'   \item{adult_per_redd}{adults per redd}
#'   \item{density}{maximum rearing densities by habitat type}
#'   \item{survival}{seasonal survival by habitat type}
#'   \item{lr_wd_s_bank}{summer large river wood density associated with banks}
#'   \item{lr_wd_s_bar}{summer large river wood density associated with bars}
#'   \item{lr_wd_w_bank}{winter large river wood density associated with banks}
#'   \item{lr_wd_w_bar}{winter large river wood density associated with bars}
#'   \item{prespawn_surv_raw}{natural prespawn mortality}
#' }
#' @source \describe{Various sources, see LCM report}
'params_hab_coho'

#' Summer/Fall Chinook habitat parameters for habitat model
#'
#' A dataset containing habitat parameters
#'
#' @format A named list with 10 elements:
#' \describe{
#'   \item{fecundity}{fecundity}
#'   \item{redd_area}{size of redd}
#'   \item{adult_per_redd}{adults per redd}
#'   \item{density}{maximum rearing densities by habitat type}
#'   \item{survival}{seasonal survival by habitat type}
#'   \item{lr_wd_s_bank}{summer large river wood density associated with banks}
#'   \item{lr_wd_s_bar}{summer large river wood density associated with bars}
#'   \item{lr_wd_w_bank}{winter large river wood density associated with banks}
#'   \item{lr_wd_w_bar}{winter large river wood density associated with bars}
#'   \item{prespawn_surv_raw}{baseline prespawn mortality}
#' }
#' @source \describe{Various sources, see LCM report}
'params_hab_fall_chinook'

#' Spring Chinook habitat parameters for habitat model - DEPRECATED
#'
#' A dataset containing habitat parameters
#'
#' @format A named list with 9 elements:
#' \describe{
#'   \item{fecundity}{fecundity}
#'   \item{redd_area}{size of redd}
#'   \item{adult_per_redd}{adults per redd}
#'   \item{density}{maximum rearing densities by habitat type}
#'   \item{survival}{seasonal survival by habitat type}
#'   \item{lr_wd_s_bank}{summer large river wood density associated with banks}
#'   \item{lr_wd_s_bar}{summer large river wood density associated with bars}
#'   \item{lr_wd_w_bank}{winter large river wood density associated with banks}
#'   \item{lr_wd_w_bar}{winter large river wood density associated with bars}
#' }
#' @source \describe{Various sources, see LCM report}
'params_hab_spring_chinook'

#' Steelhead habitat parameters for habitat model
#'
#' A dataset containing habitat parameters
#'
#' @format A named list with 10 elements:
#' \describe{
#'   \item{fecundity}{fecundity}
#'   \item{redd_area}{size of redd}
#'   \item{adult_per_redd}{adults per redd}
#'   \item{density}{maximum rearing densities by habitat type}
#'   \item{survival}{seasonal survival by habitat type}
#'   \item{lr_wd_s_bank}{summer large river wood density associated with banks}
#'   \item{lr_wd_s_bar}{summer large river wood density associated with bars}
#'   \item{lr_wd_w_bank}{winter large river wood density associated with banks}
#'   \item{lr_wd_w_bar}{winter large river wood density associated with bars}
#'   \item{prespawn_surv_raw}{baseline prespawn mortality}
#' }
#' @source \describe{Various sources, see LCM report}
'params_hab_steelhead'


