#' Check git status (tool used during package development)
#'
#' @return Vector of information related to git status
check_git_status <- function(){

  cur_branch <- system2('git', c('branch', '--show-current'), stdout = TRUE)

  diffs <- system2('git', c('diff', '--shortstat'), stdout = TRUE)
  is_dirty <- !identical(diffs, character(0))
  system2('git', c("fetch", "--tags")) # update tags
  cur_tag <- system2('git', c('describe', '--tag'), stdout = TRUE)
  cur_commit <- cur_tag

  if (is_dirty){
    commit_date <- Sys.Date() # use today for dirty branches
    dir_name <- paste(cur_commit, "dirty", sep = "-")
  } else {
    commit_date <-system2('git', c('log', '-1', '--format=%cs'), stdout = TRUE)
    dir_name <- cur_commit
  }

  # check to make sure package is up to date:
  if(packageDate("harp") < commit_date | is.na(packageDate("harp"))){
    stop("Outdated package version installed.
         Reinstall package for use with furrr")}

  c(commit_date = as.character(commit_date), dir_name = dir_name,
    cur_branch = cur_branch, cur_tag = cur_tag)
}
