# create vectors to control hatchery fish movement

# North Fork outmigration basins
nf_out_basins <- tribble(
  ~noaa_subba,                            ~nf_out,
  "mainstem_Stillaguamish",               0.25,
  "mainstem_North_Fork_Stillaguamish_01", 0.25,
  "mainstem_North_Fork_Stillaguamish_02", 0.25,
  "mainstem_North_Fork_Stillaguamish_03", 0.25)

# South Fork outmigration basins
sf_out_basins <- tribble(
  ~noaa_subba,                            ~sf_out,
  "mainstem_Stillaguamish",               0.5,
  "mainstem_South_Fork_Stillaguamish_01", 0.5)

# North Fork Destination basins, where hatchery fish stray TO
nf_dst_basins <- tribble(
  ~noaa_subba,                            ~nf_dist,
  "mainstem_North_Fork_Stillaguamish_01", 0.032,
  "mainstem_North_Fork_Stillaguamish_02", 0.262,
  "mainstem_North_Fork_Stillaguamish_03", 0.561,
  "mainstem_North_Fork_Stillaguamish_04", 0.051,
  "Boulder_River",                        0.011,
  "Squire_Creek",                         0.083)

# South Fork Destination basins
sf_dst_basins <- tribble(
  ~noaa_subba,                            ~sf_dist,
  "mainstem_South_Fork_Stillaguamish_01", 0.610,
  "mainstem_South_Fork_Stillaguamish_02", 0.049,
  "Jim_Creek",                            0.341)

# combine hatchery table into a single table
hatchery_table <- subbasin_names %>%
  select(noaa_subba, subbasin_num) %>%
  left_join(nf_out_basins, by = "noaa_subba") %>%
  left_join(sf_out_basins, by = "noaa_subba") %>%
  left_join(nf_dst_basins, by = "noaa_subba") %>%
  left_join(sf_dst_basins, by = "noaa_subba") %>%
  mutate(across(c(nf_out, sf_out, nf_dist, sf_dist), ~replace_na(., 0)))

# North fork basins that could provide broodstock
bs_subbasins <- subbasin_names %>%
  dplyr::mutate(
    bs_basin = dplyr::if_else(
      grepl("North_Fork", subb_group), # only pick NF subbasins
      TRUE,
      FALSE)) %>%
  dplyr::pull(bs_basin) # just get subbasin number
